using System.Linq;
using FluentAssertions;
using NUnit.Framework;

namespace E2ETests.Subscriber;

[Order(200)]
[TestFixture]
public class SubscriberTestHappyPath : SubscriberTestBase {
    [Test]
    public void GetAvailableSubmissions_WithDestinationId_ShouldReturnSubmissionsForPickupDto() {
        // Act
        var submissions = base.subscriber.GetAvailableSubmissions(desitnationId, 0, 100).ToList();

        // Assert
        submissions.Count().Should().BeGreaterThan(0);
        submissions.All(s => s.DestinationId == desitnationId).Should().BeTrue();
    }

    [Test]
    public void GetAvailableSubmissions_WithOutDestinationId_ShouldReturnSubmissionsForPickupDto() {
        // Act
        var submissions = base.subscriber.GetAvailableSubmissions(null, 0, 100).ToList();

        // Assert
        submissions.Count().Should().BeGreaterThan(0);
    }


    [Test]
    public void GetSubmission_WithSubmissionId_ShouldReturnSubmissionsForPickupDto() {
        // Arrange
        var submissions = base.subscriber.GetAvailableSubmissions(null, 0, 100).ToList();
        submissions.Count().Should().BeGreaterThan(0);

        var submissionId = submissions.First().SubmissionId;
        // Act
        var dto = subscriber.RequestSubmission("aeff0ba9-163b-49d9-83d1-6a9e735e6ed7");

        // Assert
        dto.Submission.Id.Should().Be(submissionId);
    }
}
